Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1326)

Unified Diff: chrome/browser/extensions/extension_service.h

Issue 10698014: [Sync] Rename csync namespace to syncer (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Address comments Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/extensions/app_sync_data_unittest.cc ('k') | chrome/browser/extensions/extension_service.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/extensions/extension_service.h
diff --git a/chrome/browser/extensions/extension_service.h b/chrome/browser/extensions/extension_service.h
index d67d9ecd386fbe23dcff9d0b8dacc1aaa9c3d712..903a82e3228e6bc5dded60f0c1a5d2a9202eb2a0 100644
--- a/chrome/browser/extensions/extension_service.h
+++ b/chrome/browser/extensions/extension_service.h
@@ -72,7 +72,7 @@ class ExtensionBluetoothEventRouter;
class ExtensionInputMethodEventRouter;
}
-namespace csync {
+namespace syncer {
class SyncData;
class SyncErrorFactory;
}
@@ -91,7 +91,7 @@ class WebNavigationEventRouter;
// This is an interface class to encapsulate the dependencies that
// various classes have on ExtensionService. This allows easy mocking.
-class ExtensionServiceInterface : public csync::SyncableService {
+class ExtensionServiceInterface : public syncer::SyncableService {
public:
// A function that returns true if the given extension should be
// included and false if it should be filtered out. Identical to
@@ -420,18 +420,18 @@ class ExtensionService
virtual void CheckForUpdatesSoon() OVERRIDE;
- // csync::SyncableService implementation.
- virtual csync::SyncError MergeDataAndStartSyncing(
+ // syncer::SyncableService implementation.
+ virtual syncer::SyncError MergeDataAndStartSyncing(
syncable::ModelType type,
- const csync::SyncDataList& initial_sync_data,
- scoped_ptr<csync::SyncChangeProcessor> sync_processor,
- scoped_ptr<csync::SyncErrorFactory> sync_error_factory) OVERRIDE;
+ const syncer::SyncDataList& initial_sync_data,
+ scoped_ptr<syncer::SyncChangeProcessor> sync_processor,
+ scoped_ptr<syncer::SyncErrorFactory> sync_error_factory) OVERRIDE;
virtual void StopSyncing(syncable::ModelType type) OVERRIDE;
- virtual csync::SyncDataList GetAllSyncData(
+ virtual syncer::SyncDataList GetAllSyncData(
syncable::ModelType type) const OVERRIDE;
- virtual csync::SyncError ProcessSyncChanges(
+ virtual syncer::SyncError ProcessSyncChanges(
const tracked_objects::Location& from_here,
- const csync::SyncChangeList& change_list) OVERRIDE;
+ const syncer::SyncChangeList& change_list) OVERRIDE;
// Gets the sync data for the given extension, assuming that the extension is
// syncable.
@@ -618,7 +618,7 @@ class ExtensionService
AppShortcutManager* app_shortcut_manager() { return &app_shortcut_manager_; }
// Specialization of csync::SyncableService::AsWeakPtr.
base::WeakPtr<ExtensionService> AsWeakPtr() { return base::AsWeakPtr(this); }
private:
« no previous file with comments | « chrome/browser/extensions/app_sync_data_unittest.cc ('k') | chrome/browser/extensions/extension_service.cc » ('j') | no next file with comments »
@@ -618,7 +618,7 @@ class ExtensionService
AppShortcutManager* app_shortcut_manager() { return &app_shortcut_manager_; }
- // Specialization of csync::SyncableService::AsWeakPtr.
+ // Specialization of syncer::SyncableService::AsWeakPtr.
base::WeakPtr<ExtensionService> AsWeakPtr() { return base::AsWeakPtr(this); }
private:

Powered by Google App Engine
This is Rietveld 408576698